Examples
========

For minimal examples you can quickly run, see the **Example** section for each of these
functions:

:func:`cappr.openai.classify.predict`

:func:`cappr.huggingface.classify.predict`

:func:`cappr.llama_cpp.classify.predict`

:func:`cappr.openai.classify.predict_examples`

:func:`cappr.huggingface.classify.predict_examples`

:func:`cappr.llama_cpp.classify.predict_examples`

Also see the `Usage <https://github.com/kddubey/cappr/tree/main#usage>`_ section in the
repo README.

For examples of fully worked out tasks, see the `demos in the repo
<https://github.com/kddubey/cappr/tree/main/demos>`_.
